@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Exporter;
 use parent 'Exporter';
@@ -128,19 +128,26 @@ sub is_gmt   { !shift->{impl}->[Time::Piece::c_islocal] }
 
 sub as
 {
-	my ($self, $newclass) = @_;
+	my ($self, $conv_spec) = @_;
 
-	if ($newclass eq 'Time::Piece')
+	if ( $conv_spec =~ /^(\W)(\w+)$/ )
+	{
+		my $fmt = join($1, map { "%$_" } split('', $2));
+		return $self->strftime($fmt);
+	}
+	if ( $conv_spec eq 'Time::Piece' )
 	{
 		return $self->{impl};
 	}
 	else
 	{
-		croak("Don't know how to convert " . ref( $self) . " to $newclass");
+		croak("Don't know how to convert " . ref( $self) . " to $conv_spec");
 	}
 }
 
 
+# ACCESSORS
+
 sub year		{ shift->{impl}->year }
 sub month		{ shift->{impl}->mon }
 sub day			{ shift->{impl}->mday }
@@ -152,6 +159,9 @@ sub time_zone	{ shift->{impl}->strftime('%Z') }
 sub day_of_week	{ shift->{impl}->day_of_week || 7 }						# change Sunday from 0 to 7
 sub quarter		{ int(shift->{impl}->_mon / 3) + 1 }					# calc quarter from (zero-based) month
 
+
+# FORMATTERS
+
 sub strftime
 {
 	my ($self, $format) = @_;
@@ -163,6 +173,14 @@ sub strftime
 	return $self->{impl}->strftime($format);
 }
 
+sub iso8601		{ shift->{impl}->datetime }
+*iso = \&iso8601;
+
+
+# MATH METHODS
+
+sub add_months	{ shift->{impl}->add_months(@_) }
+
 
 ########################
 # OVERLOADED OPERATORS #
@@ -211,7 +229,7 @@ Date::Easy::Datetime - easy datetime class
 
 =head1 VERSION
 
-This document describes version 0.02 of Date::Easy::Datetime.
+This document describes version 0.03 of Date::Easy::Datetime.
 
 =head1 SYNOPSIS
 
@@ -223,6 +241,9 @@ This document describes version 0.02 of Date::Easy::Datetime.
     # addition and subtraction work in increments of seconds
     my $this_time_yesterday = now - 60*60*24;
     my $after_30_minutes = now + 30 * 60;
+    # or can add or subtract months
+    my $next_month = now->add_months(1);
+    my $last_month = now->add_months(-1);
 
     # if you prefer UTC
     my $utc = datetime(UTC => "2016-03-07 01:22:16PST-0800");
@@ -244,6 +265,8 @@ This document describes version 0.02 of Date::Easy::Datetime.
     my $dw = $dt->day_of_week;
 
     say $dt->strftime("%Y-%m-%dT%H:%M:%S%z");
+    say $dt->iso8601;
+    say $dt->as("/Ymd");
 
     my $tp = $dt->as('Time::Piece');
 
@@ -438,15 +461,46 @@ Returns the day of the week from 1 (Monday) to 7 (Sunday).
 
 Returns the quarter of the year, based on the month (1 - 4).
 
-=head3 strftime
+=head3 strftime($fmt)
 
 Calls L<Time::Piece>'s C<strftime>.  See those docs for full details.
 
-=head3 as
+=head3 iso8601
 
-Converts the datetime to the given class, if possible.  Currently, the only acceptable classname is
-L<Time::Piece>.  (Since a Date::Easy::Datetime is stored internally as a Time::Piece object, this is
-a trivial lookup.)
+Calls L<Time::Piece>'s C<datetime>, which produces an ISO 8601 formatted datetime.
+
+=head3 iso
+
+Alias for L</iso8601>, in case you can never remember the exact digits (like me).
+
+=head3 as($conv_spec)
+
+Tries to convert the datetime according to the supplied conversion specification.  There are two
+possible formats for the spec:
+
+=over
+
+=item *
+
+If the spec consists of a non-letter followed by one or more letters (and nothing else), C<as> will
+convert this to a time format to be passed to L</strftime>.  For instance, the spec "-Ymd" is
+converted to "%Y-%m-%d", and ":HMS" is converted to "%H:%M:%S".  This allows conversion to a string
+using much more compact formats, such as "/mdy" or even S<" abdYZ">.
+
+=item *
+
+Otherwise, the spec is expected to be a classname, and C<as> tries to convert the datetime to the
+given class.  Currently, the only acceptable classname is L<Time::Piece>.  (Since a
+Date::Easy::Datetime is stored internally as a Time::Piece object, this is a trivial lookup.)
+
+=back
+
+=head3 add_months($num)
+
+Calls L<Time::Piece>'s C<add_months> to add a given number of months and return a new datetime
+object.  The original datetime is not modified.  Supply a negative number to subtract months.  See
+the L<Time::Piece> docs for full details, especially as regards what happens when you try to add
+months to dates at the ends of months.
 
 =head2 Overloaded Operators
 
@@ -528,7 +582,7 @@ Buddy Burden <barefootcoder@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Buddy Burden.
+This software is Copyright (c) 2017 by Buddy Burden.
 
 This is free software, licensed under:
 
